@@ -42,8 +42,14 @@ def connect(account=None,passw=None):
     if account==None and passw==None:
         res= mt5.initialize()
     else:
+        account=int(account)
         res= mt5.initialize(login=account, password=passw)
     global ac,path,datapath,commonDatapath,company,platform,connected
+    if res!=True:
+        if account==None:
+            print('Error trying to connect to last account!!')
+        else:
+            print('Error trying to connect to account: ',account)
     info=mt5.account_info()
     if info.margin_so_mode !=mt5.ACCOUNT_MARGIN_MODE_RETAIL_NETTING:
         print("It is NOT netting, but B3 should be netting trade mode!! Error!!")  # B3 is Netting!!
@@ -120,6 +126,7 @@ def isMarketOpen(asset='B3SA3'):
   #      else:
   #          return False
   #  return False
+  mt5.symbol_select(asset) # it makes sure that the symbol is present in Market Watch View
   t_secs=mt5.symbol_info_tick(asset).time # time in seconds
   now_dt=datetime.now(etctz)+timedelta(hours=-3)
   last_tick_dt=datetime.fromtimestamp(t_secs,etctz)
